import pyglet
from pyglet import resource
from pyglet.window import key

import base
import data
import weapons

class Player(base.Character, key.KeyStateHandler):
	collide_type = "player"
	
	mass = 75.
	move_speed = 800.
	health = 100.
	
	weapons = []
	weapon_index = 0
	
	weapon = None
	is_shooting = False
	
	def __init__(self, batch=None):
		img = resource.image(data.filepath('player.png'))
		super(Player, self).__init__(img, batch=batch)
		self.reset()
		
	def reset(self):
		self.x, self.y = data.WINDOW_WIDTH / 2, data.WINDOW_HEIGHT / 2
		
		pistol = weapons.Pistol()
		pistol.parent_character = self
		flamer = weapons.FlameThrower()
		flamer.parent_character = self
		rocket = weapons.ScatterRocket()
		rocket.parent_character = self
		nuke = weapons.NuclearRocket()
		nuke.parent_character = self
		
		self.weapons = [pistol, flamer, rocket, nuke]
		self.weapon = self.weapons[ self.weapon_index ]
		
	def update(self, dt):
		self.weapon.update(dt)
		if ( self.is_shooting ):
			self.shoot()
			
		speed_change = self.move_speed * dt

		# Update movement
		if self[key.LEFT]:
			self.dx -= speed_change
		if self[key.RIGHT]:
			self.dx += speed_change
		if self[key.UP]:
			self.dy += speed_change
		if self[key.DOWN]:
			self.dy -= speed_change
		
		# if we're trying to go off the edge of the screen have a bounce back
		#if (self.dx > 0 and 
		
		# always face the mouse cursor
		self.rotation = data.vector_to_rotation( data.mousex - self.x, data.mousey - self.y )
		
		super(Player, self).update(dt)
	
	def shoot(self):
		self.weapon.fire(self.x, self.y, data.mousex, data.mousey)
		
	def change_weapon(self, index_change):
		self.weapon_index = (self.weapon_index + index_change) % len(self.weapons)
		self.weapon = self.weapons[ self.weapon_index ]
		
